# SPDX-FileCopyrightText: 2016, 2018 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from gi.repository import Gtk

from .digitalclock import DigitalClock
from .countdownlabel import CountdownLabel
from .preferencedialog import PreferenceDialog


class CountdownApplicationWindow(Gtk.ApplicationWindow):
    def __init__(self, app):
        Gtk.ApplicationWindow.__init__(self, application=app)

        header = Gtk.HeaderBar(has_subtitle=False, show_close_button=True, title="Countdown")
        self.set_titlebar(header)

        gear = Gtk.Button.new_from_icon_name('appointment-new-symbolic', Gtk.IconSize.BUTTON)
        gear.connect('clicked', self._on_preferences)

        header.pack_end(gear)

        grid = Gtk.Grid(orientation=Gtk.Orientation.VERTICAL)
        self.add(grid)

        self._clock = DigitalClock()
        grid.add(self._clock)
        self._count = CountdownLabel()
        grid.add(self._count)

    def _on_preferences(self, btn):
        dialogue = PreferenceDialog(self._count.target)
        dialogue.set_transient_for(self)
        dialogue.show_all()
        dialogue.connect('response', self._on_preferences_response)

    def _on_preferences_response(self, dialogue, resp_id):
        if resp_id == Gtk.ResponseType.ACCEPT:
            self._count.target = dialogue.datetime

        dialogue.destroy()
