# SPDX-FileCopyrightText: 2018 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

import math

from gi.repository import GLib, GObject, Gtk, Pango


class CountdownLabel(Gtk.Label):
    """A label that displays a countdown to a specific time"""

    def __init__(self):
        Gtk.Label.__init__(self)

        # Properties
        self._target = GLib.DateTime.new_now_local()

        ctx = self.get_style_context()
        ctx.add_class('countdown-label')
        self._update_clock()
        GLib.timeout_add_seconds(1, self._update_clock)

    def _update_clock(self):
        now = GLib.DateTime.new_now_local()
        diff = self._target.difference(now)

        text = self._format_difference(diff)
        self.set_label(text)
        return True

    def _format_difference(self, diff):
        diff = (abs(diff) / GLib.TIME_SPAN_SECOND) + 1
        seconds = int(diff % 60)
        diff /= 60
        minutes = int(diff % 60)
        diff /= 60
        hours = int(diff % 24)
        diff /= 24
        days = int(diff)

        return "{:3d} days\n{:3d} hours\n{:3d} minutes\n{:3d} seconds".format(days, hours, minutes, seconds)

    @GObject.Property(type=GLib.DateTime)
    def target(self):
        return self._target

    @target.setter
    def target(self, target):
        self._target = target
        self._update_clock()
