# SPDX-FileCopyrightText: 2018 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from datetime import datetime
import sys

from gi import require_version
require_version('Gtk', '3.0')
from gi.repository import Gdk, Gio, Gtk, Pango

from .aboutdialog import AboutDialog
from .countdownapplicationwindow import CountdownApplicationWindow
from .preferencedialog import PreferenceDialog


class CountdownApplication(Gtk.Application):
    def __init__(self):
        Gtk.Application.__init__(self, application_id="uk.me.bcowan.Countdown")

    def do_activate(self):
        win = CountdownApplicationWindow(self)
        win.show_all()

    def do_startup(self):
        Gtk.Application.do_startup(self)

        about_action = Gio.SimpleAction(name="about")
        about_action.connect("activate", self._on_about)
        self.add_action(about_action)

        quit_action = Gio.SimpleAction(name="quit")
        quit_action.connect("activate", self._on_quit)
        self.add_action(quit_action)

        provider = Gtk.CssProvider()
        provider.load_from_resource('/uk/me/bcowan/countdown/countdown.css')
        screen = Gdk.Screen.get_default()
        ctx = Gtk.StyleContext()
        ctx.add_provider_for_screen(screen, provider,
                                    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)

# Turn this into a lambda if possible
    def _on_about_response(self, dialogue, resp_id):
        dialogue.destroy();

    def _on_about(self, action, param):
        win = self.props.active_window
        dialogue = AboutDialog()
        dialogue.set_transient_for(win)
        dialogue.show_all()
        dialogue.connect("response", self._on_about_response)

    def _on_quit(self, action, param):
        self.quit()

def main(version):
    app = CountdownApplication()
    return app.run(sys.argv)
