# SPDX-FileCopyrightText: 2016-2018 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: LGPL-3.0-or-later

from gi.repository import GLib, GObject, Gtk, Pango


class PreferenceDialog(Gtk.Dialog):
    """A dialogue for choosing preferences"""
    __gtype_name__ = 'PreferenceDialog'

    def __init__(self, target):
        Gtk.Dialog.__init__(self, title="Preferences", flags=Gtk.DialogFlags.MODAL, resizable=False, use_header_bar=True)

        self.add_button("_Cancel", Gtk.ResponseType.CANCEL)

        apply = self.add_button("_Apply", Gtk.ResponseType.ACCEPT)
        apply.get_style_context().add_class(Gtk.STYLE_CLASS_SUGGESTED_ACTION)

        grid = Gtk.Grid()
        self.get_content_area().add(grid)

        # [H]:[M]:[S] part
        self._hour = Gtk.SpinButton.new_with_range(0, 23, 1)
        self._hour.props.orientation = Gtk.Orientation.VERTICAL
        self._hour.props.value = target.get_hour()
        self._hour.connect("output", self._on_spin_output)
        grid.add(self._hour)
        label = Gtk.Label(label=":")
        grid.add(label)
        self._minute = Gtk.SpinButton.new_with_range(0, 59, 1)
        self._minute.props.orientation = Gtk.Orientation.VERTICAL
        self._minute.props.value = target.get_minute()
        self._minute.connect("output", self._on_spin_output)
        grid.add(self._minute)
        label = Gtk.Label(label=":")
        grid.add(label)
        self._second = Gtk.SpinButton.new_with_range(0, 59, 1)
        self._second.props.orientation = Gtk.Orientation.VERTICAL
        self._second.props.value = target.get_second()
        self._second.connect("output", self._on_spin_output)
        grid.add(self._second)

        # Calendar
        self._calendar = Gtk.Calendar()
        self._calendar.select_day(target.get_day_of_month())
        self._calendar.select_month(target.get_month() - 1, target.get_year())
        grid.attach_next_to(self._calendar, self._hour, Gtk.PositionType.TOP, 5, 1)

    def _on_spin_output(self, spin):
        value = int(spin.props.value)
        text = "{:02d}".format(value)
        spin.props.text = text
        return True

    @GObject.Property(type=GLib.DateTime)
    def datetime(self):
        (year, month, day) = self._calendar.get_date()
        month += 1
        hour = int(self._hour.props.value)
        minute = int(self._minute.props.value)
        second = int(self._second.props.value)

        return GLib.DateTime.new_local(year, month, day, hour, minute, second)
